require 'uu/os/rest/dto'
require 'uu/os/uesuri'
require 'uu/finman/financialtransaction/financial_transaction_dto'

# Module Unicorn Universe
module UU

  # Module Finman
  module Finman

    # Module of finman Financial transaction
    module FinancialTransaction

      # DTO for get attributes command of financial transfer.
      class TransferAttributes < FinancialTransactionDTO

        # URI of the financial transaction.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :uri

        # URI of meta artifact of the financial transaction.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :meta_artifact_uri

        # Name of the financial transaction.
        # @param [String]
        # @return [String]
        attr_accessor :name

        # Code of the financial transaction.
        # @param [String]
        # @return [String]
        attr_accessor :code

        # Description of the financial transaction.
        # @param [String]
        # @return [String]
        attr_accessor :description

        # URI of role competent for the financial transaction.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :competent_role_uri

        # URI of container of the financial transaction.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :location_uri

        # URI of organizational unit of the financial transaction.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :organizational_unit_uri

        # Security level of the financial transaction.
        # @param [String, UU::OS::Artifact::SecurityLevel]
        # @return [UU::OS::Artifact::SecurityLevel]
        attr_accessor :security_level

        # Creation stamp of the financial transaction.
        # @param [String]
        # @return [String]
        attr_accessor :creation_stamp

        # Creation time of the financial transaction.
        # @param [String, Time]
        # @return [String]
        attr_accessor :creation_time

        # Modification stamp of the financial transaction.
        # @param [String]
        # @return [String]
        attr_accessor :modification_stamp

        # Modification time of the financial transaction.
        # @param [String, Time]
        # @return [String]
        attr_accessor :modification_time

        # Version of the financial transaction.
        # @param [String]
        # @return [String]
        attr_accessor :version

        # Name of current state of the financial transaction.
        # @param [String]
        # @return [String]
        attr_accessor :state_name

        # Comment of current state of the financial transaction.
        # @param [String]
        # @return [String]
        attr_accessor :state_comment

        # Type of current state of the financial transaction.
        # @param [UU::OS::Artifact::ArtifactStateType]
        # @return [UU::OS::Artifact::ArtifactStateType]
        attr_accessor :state_type

        # Flag of width of sheets of the financial transaction.
        # @param [String]
        # @return [String]
        attr_accessor :width

        # URI of the icon of the financial transaction.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :icon_uri

        # UESURI of the entity type of the artifact
        # @param [String]
        # @return [String]
        attr_accessor :entity_type_uri

        # Amount of the Financial Transaction without vat.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :amount_without_vat

        # Amount of the Financial Transaction with vat.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :amount_with_vat

        # UESURI of complementary transfer to this reinvoicing transfer.
        # Set only for reinvoicing transfers
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :complementary_transfer_uri

        # Specifies which side controls transaction (CREDIT or DEBIT).
        # @param [ControlSide]
        # @return [ControlSide]
        attr_accessor :control_side

        # UESURI of Contract.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :contract_uri

        # Code of cost item.
        # @param [String]
        # @return [String]
        attr_accessor :cost_item_code

        # Number of credit account.
        # @param [String]
        # @return [String]
        attr_accessor :credit_account_number

        # UESURI of credit account artifact.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :credit_account_uri

        # UESURI of the credit business case
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :credit_business_case_uri

        # Description for credit side.
        # @param [String]
        # @return [String]
        attr_accessor :credit_description

        # UESURI of credit financial category.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :credit_financial_category_uri

        # Number of debit account.
        # @param [String]
        # @return [String]
        attr_accessor :debit_account_number

        # UESURI of debit account artifact.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :debit_account_uri

        # UESURI of the debit business case.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :debit_business_case_uri

        # Description for debit side.
        # @param [String]
        # @return [String]
        attr_accessor :debit_description

        # UESURI of debit financial category.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :debit_financial_category_uri

        # Date the payment is expected to be payed to.
        # @param [String, Time]
        # @return [String]
        attr_accessor :expected_pay_date

        # Amount in other side currency, specified by user
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :explicit_amount

        # Type of financial transaction. Item from enumeration {FinancialTransactionType}
        # Possible values: CASH or NONCASH
        # @param [FinancialTransactionType]
        # @return [FinancialTransactionType]
        attr_accessor :financial_transaction_type

        # Class of financial transaction (specifies if it is Payment, Transfer, Expost payment or Credit note)
        # @param [FinancialTransactionClass]
        # @return [FinancialTransactionClass]
        attr_accessor :financial_transaction_class

        # Code of income item.
        # @param [String]
        # @return [String]
        attr_accessor :income_item_code


        # True states that the transfer will be automatically confirmed on the expected paydate.
        # @param [TrueClass, FalseClass]
        # @return [TrueClass, FalseClass]
        attr_accessor :is_ready_to_be_paid

        # Pay date of the transaction.
        # @param [String, Time]
        # @return [String]
        attr_accessor :pay_date

        # Probability of payment realization in %.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :realization_probability

        # UESURI of financial category the amount will be reinvoiced from.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :reinvoice_from_category_uri

        # UESURI of financial category the amount will be reinvoiced to.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :reinvoice_to_category_uri

        # Code of item the amount will be reinvoiced on.
        # @param [String]
        # @return [String]
        attr_accessor :reinvoice_from_item

        # Code of item the amount will be reinvoiced on.
        # @param [String]
        # @return [String]
        attr_accessor :reinvoice_on_item

        # Identifies type of reinvoicing. Possible values: INCOMES_INCOMES, COSTS_COSTS
        # @param [ReinvoicingType]
        # @return [ReinvoicingType]
        attr_accessor :reinvoicing_type

        # Vat date of the transaction.
        # @param [String, Time]
        # @return [String]
        attr_accessor :vat_date

        # Vat rate.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :vat_rate

        # Code of credit side currency.
        # @param [String]
        # @return [String]
        attr_accessor :credit_side_currency

        # Code of debit side currency.
        # @param [String]
        # @return [String]
        attr_accessor :debit_side_currency

        # Code of transaction currency.
        # @param [String]
        # @return [String]
        attr_accessor :transaction_currency

        # Variable symbol.
        # @param [String]
        # @return [String]
        attr_accessor :variable_symbol

        # Related links(URI, label) in JSON format.
        # @param [String]
        # @return [String]
        attr_accessor :related_links

        def uri
          attributes[:uri]
        end

        def uri=(val)
          if val
            attributes[:uri] = UU::OS::UESURI.new(val)
          else
            attributes[:uri] = nil
          end
        end

        def meta_artifact_uri
          attributes[:metaArtifactUri]
        end

        def meta_artifact_uri=(val)
          if val
            attributes[:metaArtifactUri] = UU::OS::UESURI.new(val)
          else
            attributes[:metaArtifactUri] = nil
          end
        end

        def name
          attributes[:name]
        end

        def name=(val)
          attributes[:name] = val
        end

        def code
          attributes[:code]
        end

        def code=(val)
          attributes[:code] = val
        end

        def description
          attributes[:description]
        end

        def description=(val)
          attributes[:description] = val
        end

        def competent_role_uri
          attributes[:competentRoleUri]
        end

        def competent_role_uri=(val)
          if val
            attributes[:competentRoleUri] = UU::OS::UESURI.new(val)
          else
            attributes[:competentRoleUri] = nil
          end
        end

        def location_uri
          attributes[:locationUri]
        end

        def location_uri=(val)
          if val
            attributes[:locationUri] = UU::OS::UESURI.new(val)
          else
            attributes[:locationUri] = nil
          end
        end

        def organizational_unit_uri
          attributes[:organizationalUnitUri]
        end

        def organizational_unit_uri=(val)
          if val
            attributes[:organizationalUnitUri] = UU::OS::UESURI.new(val)
          else
            attributes[:organizationalUnitUri] = nil
          end
        end

        def security_level
          attributes[:securityLevel]
        end

        def security_level=(val)
          attributes[:securityLevel] = val
        end

        def creation_stamp
          attributes[:creationStamp]
        end

        def creation_stamp=(val)
          attributes[:creationStamp] = val
        end

        def creation_time
          attributes[:creationTime]
        end

        def creation_time=(val)
          attributes[:creationTime] = val
        end

        def modification_stamp
          attributes[:modificationStamp]
        end

        def modification_stamp=(val)
          attributes[:modificationStamp] = val
        end

        def modification_time
          attributes[:modificationTime]
        end

        def modification_time=(val)
          attributes[:modificationTime] = val
        end

        def version
          attributes[:version]
        end

        def version=(val)
          attributes[:version] = val
        end

        def state_name
          attributes[:stateName]
        end

        def state_name=(val)
          attributes[:stateName] = val
        end

        def state_comment
          attributes[:stateComment]
        end

        def state_comment=(val)
          attributes[:stateComment] = val
        end

        def state_type
          attributes[:stateType]
        end

        def state_type=(val)
          attributes[:stateType] = val
        end

        def width
          attributes[:width]
        end

        def width=(val)
          attributes[:width] = val
        end

        def icon_uri
          attributes[:iconUri]
        end

        def icon_uri=(val)
          if val
            attributes[:iconUri] = UU::OS::UESURI.new(val)
          else
            attributes[:iconUri] = nil
          end
        end

        def entity_type_uri
          attributes[:entityTypeUri]
        end

        def entity_type_uri=(val)
          if val
            attributes[:entityTypeUri] = UU::OS::UESURI.new(val)
          else
            attributes[:entityTypeUri] = nil
          end
        end

        def amount_without_vat
          attributes[:amountWithoutVat]
        end

        def amount_without_vat=(val)
          attributes[:amountWithoutVat] = val
        end

        def amount_with_vat
          attributes[:amountWithVat]
        end

        def amount_with_vat=(val)
          attributes[:amountWithVat] = val
        end

        def complementary_transfer_uri
          attributes[:complementaryTransferUri]
        end

        def complementary_transfer_uri=(val)
          if val
            attributes[:complementaryTransferUri] = UU::OS::UESURI.new(val)
          else
            attributes[:complementaryTransferUri] = nil
          end
        end

        def control_side
          attributes[:controlSide]
        end

        def control_side=(val)
          attributes[:controlSide] = val
        end

        def contract_uri
          attributes[:contractUri]
        end

        def contract_uri=(val)
          if val
            attributes[:contractUri] = UU::OS::UESURI.new(val)
          else
            attributes[:contractUri] = nil
          end
        end

        def cost_item_code
          attributes[:costItemCode]
        end

        def cost_item_code=(val)
          attributes[:costItemCode] = val
        end

        def credit_account_number
          attributes[:creditAccountNumber]
        end

        def credit_account_number=(val)
          attributes[:creditAccountNumber] = val
        end

        def credit_account_uri
          attributes[:creditAccountUri]
        end

        def credit_account_uri=(val)
          if val
            attributes[:creditAccountUri] = UU::OS::UESURI.new(val)
          else
            attributes[:creditAccountUri] = nil
          end
        end

        def credit_business_case_uri
          attributes[:creditBusinessCaseUri]
        end

        def credit_business_case_uri=(val)
          if val
            attributes[:creditBusinessCaseUri] = UU::OS::UESURI.new(val)
          else
            attributes[:creditBusinessCaseUri] = nil
          end
        end

        def credit_description
          attributes[:creditDescription]
        end

        def credit_description=(val)
          attributes[:creditDescription] = val
        end

        def credit_financial_category_uri
          attributes[:creditFinancialCategoryUri]
        end

        def credit_financial_category_uri=(val)
          if val
            attributes[:creditFinancialCategoryUri] = UU::OS::UESURI.new(val)
          else
            attributes[:creditFinancialCategoryUri] = nil
          end
        end

        def is_ready_to_be_paid
          attributes[:isReadyToBePaid]
        end

        def is_ready_to_be_paid=(val)
          attributes[:isReadyToBePaid] = val
        end

        def vat_date
          attributes[:vatDate]
        end

        def vat_date=(val)
          attributes[:vatDate] = val
        end

        def debit_account_number
          attributes[:debitAccountNumber]
        end

        def debit_account_number=(val)
          attributes[:debitAccountNumber] = val
        end

        def debit_account_uri
          attributes[:debitAccountUri]
        end

        def debit_account_uri=(val)
          if val
            attributes[:debitAccountUri] = UU::OS::UESURI.new(val)
          else
            attributes[:debitAccountUri] = nil
          end
        end

        def debit_business_case_uri
          attributes[:debitBusinessCaseUri]
        end

        def debit_business_case_uri=(val)
          if val
            attributes[:debitBusinessCaseUri] = UU::OS::UESURI.new(val)
          else
            attributes[:debitBusinessCaseUri] = nil
          end
        end

        def debit_description
          attributes[:debitDescription]
        end

        def debit_description=(val)
          attributes[:debitDescription] = val
        end

        def debit_financial_category_uri
          attributes[:debitFinancialCategoryUri]
        end

        def debit_financial_category_uri=(val)
          if val
            attributes[:debitFinancialCategoryUri] = UU::OS::UESURI.new(val)
          else
            attributes[:debitFinancialCategoryUri] = nil
          end
        end

        def expected_pay_date
          attributes[:expectedPayDate]
        end

        def expected_pay_date=(val)
          attributes[:expectedPayDate] = val
        end

        def explicit_amount
          attributes[:explicitAmount]
        end

        def explicit_amount=(val)
          attributes[:explicitAmount] = val
        end

        def financial_transaction_type
          attributes[:financialTransactionType]
        end

        def financial_transaction_type=(val)
          attributes[:financialTransactionType] = val
        end

        def financial_transaction_class
          attributes[:financialTransactionClass]
        end

        def financial_transaction_class=(val)
          attributes[:financialTransactionClass] = val
        end

        def income_item_code
          attributes[:incomeItemCode]
        end

        def income_item_code=(val)
          attributes[:incomeItemCode] = val
        end

        def pay_date
          attributes[:payDate]
        end

        def pay_date=(val)
          attributes[:payDate] = val
        end

        def realization_probability
          attributes[:realizationProbability]
        end

        def realization_probability=(val)
          attributes[:realizationProbability] = val
        end

        def reinvoice_from_category_uri
          attributes[:reinvoiceFromCategoryUri]
        end

        def reinvoice_from_category_uri=(val)
          if val
            attributes[:reinvoiceFromCategoryUri] = UU::OS::UESURI.new(val)
          else
            attributes[:reinvoiceFromCategoryUri] = nil
          end
        end

        def reinvoice_to_category_uri
          attributes[:reinvoiceToCategoryUri]
        end

        def reinvoice_to_category_uri=(val)
          if val
            attributes[:reinvoiceToCategoryUri] = UU::OS::UESURI.new(val)
          else
            attributes[:reinvoiceToCategoryUri] = nil
          end
        end

        def reinvoice_from_item
          attributes[:reinvoiceFromItem]
        end

        def reinvoice_from_item=(val)
          attributes[:reinvoiceFromItem] = val
        end

        def reinvoice_on_item
          attributes[:reinvoiceOnItem]
        end

        def reinvoice_on_item=(val)
          attributes[:reinvoiceOnItem] = val
        end

        def reinvoicing_type
          attributes[:reinvoicingType]
        end

        def reinvoicing_type=(val)
          attributes[:reinvoicingType] = val
        end

        def vat_rate
          attributes[:vatRate]
        end

        def vat_rate=(val)
          attributes[:vatRate] = val
        end

        def credit_side_currency
          attributes[:creditSideCurrency]
        end

        def credit_side_currency=(val)
          attributes[:creditSideCurrency] = val
        end

        def debit_side_currency
          attributes[:debitSideCurrency]
        end

        def debit_side_currency=(val)
          attributes[:debitSideCurrency] = val
        end

        def transaction_currency
          attributes[:transactionCurrency]
        end

        def transaction_currency=(val)
          attributes[:transactionCurrency] = val
        end

        def variable_symbol
          attributes[:variableSymbol]
        end

        def variable_symbol=(val)
          attributes[:variableSymbol] = val
        end

        def related_links
          attributes[:relatedLinks]
        end

        def related_links=(val)
          attributes[:relatedLinks] = val
        end

      end
    end
  end
end
